plot.robacf: Plot Robust Autocovariance and Robust Autocorrelation...

plot.robacfR Documentation

Plot Robust Autocovariance and Robust Autocorrelation Functions

Description

Plot method for objects of class "robacf".

Usage

## S3 method for class 'robacf'
plot(
  x,
  type = "h",
  xlab = "Lag",
  ylab = NULL,
  ylim = NULL,
  main = NULL,
  max.mfrow = 6,
  ask = Npgs > 1 && dev.interactive(),
  mar = if (nser > 2) c(3, 2, 2, 0.8) else par("mar"),
  oma = if (nser > 2) c(1, 1.2, 1, 1) else par("oma"),
  mgp = if (nser > 2) c(1.5, 0.6, 0) else par("mgp"),
  xpd = par("xpd"),
  cex.main = if (nser > 2) 1 else par("cex.main"),
  verbose = getOption("verbose"),
  ...
)

Arguments

x

an object of class "robacf".

type

the type of plot to be drawn, default to histogram like vertical lines.

xlab

the x label of the plot.

ylab

the y label of the plot.

ylim

numeric of length 2 giving the y limits for the plot.

main

overall title for the plot.

max.mfrow

positive integer; for multivariate x indicating how many rows and columns of plots should be put on one page, using par(mfrow = c(m,m))(see par).

ask

logical; if TRUE, the user is asked before a new page is started.

mar, oma, mgp, xpd, cex.main

graphics parameters as in par(*), by default adjusted to use smaller than default margins for multivariate x only.

verbose

logical. Should R report extra information on progress?

...

graphics parameters to be passed to the plotting routines.

Value

None

Contributions

plot.acf (stats) - R Core

Examples

robacf(cbind(ldeaths,mdeaths))

tsqn documentation built on March 17, 2026, 1:07 a.m.